﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using System.Text.RegularExpressions;

public class Enemy : MonoBehaviour {

    [SerializeField]
    Transform[] m_targetPositions;    // 走行ルート

    int m_targetNo = 0;             // 目標地点の配列番号

    CarController m_carController;  // 車制御用コントローラ

	// Use this for initialization
	void Start () {
        // 車制御用コントローラを取得
        m_carController = GetComponent<CarController>();
	}
	
	// Update is called once per frame
	void Update () {
        
        // 自分の位置と目標位置の差ベクトルを求める
        Vector3 targetDir = m_targetPositions[m_targetNo].position - transform.position;

        // 自分の前方向と、上記の差ベクトルの外積をとる（右にいるのか左にいるのかを調べるため）
        Vector3 axis = Vector3.Cross(transform.forward, targetDir);


        // 自分の前方向と、上記の差ベクトルから、角度の差を求める
        float angle = Vector3.Angle(transform.forward, targetDir);

        // とりあえずアクセル全開
        m_carController.Forward = true;

        if (angle > 3)
        {
            if (axis.y < 0)
            {
                m_carController.Left = true;            // ステアリングを左に切る
            }
            else if (axis.y > 0)
            {
                m_carController.Right = true;           // ステアリングを右に切る
            }

        }
    }



	/// <summary>
	/// 当たり判定エリアに入ったら
	/// </summary>
	/// <param name="other">Other.</param>
    private void OnTriggerEnter(Collider other)
    {
		if (other.gameObject.tag == "NormalRoot")
		{
			// ぶつかった相手の名前の最後の文字を取り出す
			string strNo = Regex.Replace (other.gameObject.name, @"[^0-9]", "");
			// その文字を数字に変換
			int no = int.Parse (strNo);

			// 目標エリアに入ったなら
			if (no == m_targetNo) {
				// 目標地点を次に
				m_targetNo++;
				// 1周したら目標地番号を0にする
				if (m_targetNo >= m_targetPositions.Length) {
					m_targetNo = 0;
				}
			}
		}
    }
}
